@@ -10,17 +10,15 @@ struct RarLocalTime
   uint Minute;
   uint Second;
   uint Reminder;
+  uint wDay;
+  uint yDay;
 };
 
+
 class RarTime
 {
   private:
-    Int64 GetRaw();
-    void SetRaw(Int64 RawTime);
-
     RarLocalTime rlt;
-
-    Int64 Time;
   public:
     RarTime();
 #ifdef _WIN_32
@@ -29,7 +27,7 @@ class RarTime
 #endif
 #if defined(_UNIX) || defined(_EMX)
     RarTime& operator =(time_t ut);
-    time_t RarTime::GetUnix();
+    time_t GetUnix();
 #endif
     bool operator == (RarTime &rt);
     bool operator < (RarTime &rt);
@@ -38,6 +36,8 @@ class RarTime
     bool operator >= (RarTime &rt);
     void GetLocal(RarLocalTime *lt) {*lt=rlt;}
     void SetLocal(RarLocalTime *lt) {rlt=*lt;}
+    int64 GetRaw();
+    void SetRaw(int64 RawTime);
     uint GetDos();
     void SetDos(uint DosTime);
     void GetText(char *DateStr,bool FullYear);
@@ -49,6 +49,6 @@ class RarTime
 };
 
 const char *GetMonthName(int Month);
-
+bool IsLeapYear(int Year);
 
 #endif
